from balance_service.adapters.bank_basic_adapter import BankBasicAdapter

from balance_domain.models.user_models import Bank
from balance_domain.database.settings import ConnectionDatabase


class BankAlchemyAdapter(
    ConnectionDatabase,
    BankBasicAdapter
):
    def __init__(self):
        super().__init__()

    def create(self,
               token: str,
               user_id: str):
        bank = Bank(
            token=token,
            user_id=user_id)
        self.session.add(bank)
        self.session.commit()
        self.session.refresh(bank)
        return bank

    def get_by_user_id(self, user_id: str):
        banks = self.session.query(Bank).filter(Bank.user_id == user_id).all()
        return banks



from abc import abstractmethod


class BankBasicAdapter:
    @abstractmethod
    def create(self,
               token: str,
               user_id: str):
        pass

    @abstractmethod
    def get_by_user_id(self, user_id: str):
        pass




from abc import abstractmethod


class UserBasicAdapter:
    @abstractmethod
    def create(self,
               surname: str,
               fullname: str,
               email: str,
               hashed_password: str):
        pass

    @abstractmethod
    def get_by_id(self, user_id: str):
        pass

    @abstractmethod
    def get_by_email(self, user_email: str):
        pass



from balance_service.adapters.user_basic_adapter import UserBasicAdapter

from balance_domain.models.user_models import User
from balance_domain.database.settings import ConnectionDatabase


class UserAlchemyAdapter(
    UserBasicAdapter,
    ConnectionDatabase,
):
    def __init__(self):
        super().__init__()

    def create(self,
                surname: str,
                fullname: str,
                email: str,
                hashed_password: str):
        user = User(
            surname=surname,
            fullname=fullname,
            email=email,
            hashed_password=hashed_password)
        self.session.add(user)
        self.session.commit()
        self.session.refresh(user)
        return user

    def get_by_id(self, user_id: str):
        user = self.session.query(User).filter(User.id == user_id).first()
        return user

    def get_by_email(self, user_email: str):
        user = self.session.query(User).filter(User.email == user_email).first()
        return user
